RunTree

Struct RunTree 

pub struct RunTree {
Show 14 fields pub id: Uuid, pub name: String, pub run_type: RunType, pub inputs: Value, pub outputs: Option<Value>, pub error: Option<String>, pub parent_run_id: Option<Uuid>, pub trace_id: Option<Uuid>, pub start_time: DateTime<Utc>, pub end_time: Option<DateTime<Utc>>, pub metadata: HashMap<String, Value>, pub tags: Vec<String>, pub project_name: Option<String>, pub serialized: Value,
}
Run tree node for tracing

Each run is a node in a tree, with optional parent and children. The entire trace forms a tree structure, with the root being the top-level call.

Fields

id: Uuid

Unique run ID (UUID v7 with timestamp)

name: String

Run name

run_type: RunType

Run type

inputs: Value

Input data

outputs: Option<Value>

Output data (set when run ends)

error: Option<String>

Error message (if run failed)

parent_run_id: Option<Uuid>

Parent run ID

trace_id: Option<Uuid>

Trace ID (ID of the root run)

start_time: DateTime<Utc>

Start time

end_time: Option<DateTime<Utc>>

End time

metadata: HashMap<String, Value>

Metadata

tags: Vec<String>

Tags

project_name: Option<String>

Project name (LangSmith project)

serialized: Value

Serialized representation of the component

Implementations

Source

impl RunTree

pub fn new(name: impl Into<String>, run_type: RunType, inputs: Value) -> Self

Create a new run

pub fn create_child( &self, name: impl Into<String>, run_type: RunType, inputs: Value, ) -> Self

Create a child run from this run

pub fn end(&mut self, outputs: Value)

End the run with outputs

pub fn end_with_error(&mut self, error: impl Into<String>)

End the run with an error

pub fn with_tag(self, tag: impl Into<String>) -> Self

Add a tag

pub fn with_metadata(self, key: impl Into<String>, value: Value) -> Self

Add metadata

pub fn with_project(self, project: impl Into<String>) -> Self

Set project name

pub fn duration_ms(&self) -> Option<i64>

Calculate run duration in milliseconds