pub fn clear_span_stack()Expand description
Clear the thread-local span stack.
This is primarily useful for test isolation when spans from prior tests leak into the thread-local state.
pub fn clear_span_stack()Clear the thread-local span stack.
This is primarily useful for test isolation when spans from prior tests leak into the thread-local state.